.. _cluster:

cluster
=======

This module initializes the cluster functions of the hsi-wizard package.

Module Overview
---------------

.. currentmodule:: wizard._processing.cluster

Functions
---------

.. autofunction:: compute_pairwise_distances
.. autofunction:: isodata

.. note::
  The Isodata code was inspired by `pyRadar <https://github.com/PyRadar/pyradar/>` from PyRadar.